@@ -14,11 +14,11 @@ def main():
     if len(sys.argv) == 1:
         sys.argv.append('--help')
     parser = argparse.ArgumentParser(description='X ATP CLI Client (X 自动化测试平台命令行客户端)')
-    parser.add_argument('-v', '--version', help='输出客户端版本信息', action='version', version='%(prog)s v0.2.2')
+    parser.add_argument('-v', '--version', help='输出客户端版本信息', action='version', version='%(prog)s v0.2.4')
     parser.add_argument('-d', '--demo', help='在当前目录下创建 `x_sweetest_example` 项目',
                         action='store_true')
     parser.add_argument('-r', '--run', dest='atp_server_url',
-                        help='运行 X-ATP 自动测试执行端服务 (E.g x-atp-cli -r http://127.0.0.1 -api)',
+                        help='运行 X-ATP 自动测试执行端服务 (E.g x-atp-cli -r http://127.0.0.1 -api -n 执行端001)',
                         action='store')
     parser.add_argument('-api', '--api', help='运行 API 测试执行端 (used with parameter -r)',
                         action='store_true', default=False)
